# Changelog

## [0.0.16a36](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a36) (2024-06-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a35...0.0.16a36)

**Fixed bugs:**

- fix/activation+session [\#212](https://github.com/OpenVoiceOS/OVOS-workshop/pull/212) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a35](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a35) (2024-06-18)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a34...0.0.16a35)

**Fixed bugs:**

- fix/fallback\_timeout\_handling [\#210](https://github.com/OpenVoiceOS/OVOS-workshop/pull/210) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a34](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a34) (2024-06-08)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a33...0.0.16a34)

**Merged pull requests:**

- chore: don't drag ovos-classifiers [\#209](https://github.com/OpenVoiceOS/OVOS-workshop/pull/209) ([mikejgray](https://github.com/mikejgray))

## [0.0.16a33](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a33) (2024-06-03)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a32...0.0.16a33)

**Implemented enhancements:**

- Remove vocab terms in order from longest to shortest [\#208](https://github.com/OpenVoiceOS/OVOS-workshop/pull/208) ([femelo](https://github.com/femelo))

## [0.0.16a32](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a32) (2024-06-02)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a31...0.0.16a32)

**Fixed bugs:**

- fix/mycroft\_backwards\_compat [\#206](https://github.com/OpenVoiceOS/OVOS-workshop/pull/206) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a31](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a31) (2024-05-31)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a30...0.0.16a31)

**Fixed bugs:**

- Add `is_intent` kwarg to MycroftSkill class to resolve errors [\#207](https://github.com/OpenVoiceOS/OVOS-workshop/pull/207) ([NeonDaniel](https://github.com/NeonDaniel))

## [0.0.16a30](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a30) (2024-05-28)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a29...0.0.16a30)

**Implemented enhancements:**

- feat/ovos.utterance.handled [\#205](https://github.com/OpenVoiceOS/OVOS-workshop/pull/205) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a29](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a29) (2024-05-08)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a28...0.0.16a29)

**Closed issues:**

- add support for utils 0.0.38 [\#200](https://github.com/OpenVoiceOS/OVOS-workshop/issues/200)

**Merged pull requests:**

- Update imports to support ovos-utils~=0.0.x with compat. warnings [\#201](https://github.com/OpenVoiceOS/OVOS-workshop/pull/201) ([NeonDaniel](https://github.com/NeonDaniel))

## [0.0.16a28](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a28) (2024-05-07)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a27...0.0.16a28)

**Implemented enhancements:**

- feat/wait\_while\_speaking [\#190](https://github.com/OpenVoiceOS/OVOS-workshop/pull/190) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a27](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a27) (2024-05-04)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a26...0.0.16a27)

**Fixed bugs:**

- fix/deactivate\_in\_converse/fallback [\#199](https://github.com/OpenVoiceOS/OVOS-workshop/pull/199) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a26](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a26) (2024-05-04)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a25...0.0.16a26)

**Fixed bugs:**

- refactor/skill\_activation\_before\_events [\#198](https://github.com/OpenVoiceOS/OVOS-workshop/pull/198) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a25](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a25) (2024-04-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a24...0.0.16a25)

**Implemented enhancements:**

- feat/units\_from\_session [\#197](https://github.com/OpenVoiceOS/OVOS-workshop/pull/197) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a24](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a24) (2024-04-09)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a23...0.0.16a24)

**Implemented enhancements:**

- feat/targeted OCP queries [\#195](https://github.com/OpenVoiceOS/OVOS-workshop/pull/195) ([NeonJarbas](https://github.com/NeonJarbas))

## [0.0.16a23](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a23) (2024-03-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a22...0.0.16a23)

**Fixed bugs:**

- fix/converse\_intents\_no\_match [\#193](https://github.com/OpenVoiceOS/OVOS-workshop/pull/193) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a22](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a22) (2024-03-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a21...0.0.16a22)

**Fixed bugs:**

- fix/universal converse [\#192](https://github.com/OpenVoiceOS/OVOS-workshop/pull/192) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a21](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a21) (2024-03-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a20...0.0.16a21)

## [0.0.16a20](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a20) (2024-03-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a19...0.0.16a20)

## [0.0.16a19](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a19) (2024-03-05)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a18...0.0.16a19)

**Merged pull requests:**

- Update warning log to use `log_deprecation` helper [\#188](https://github.com/OpenVoiceOS/OVOS-workshop/pull/188) ([NeonDaniel](https://github.com/NeonDaniel))

## [0.0.16a18](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a18) (2024-03-04)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a17...0.0.16a18)

**Fixed bugs:**

- Add bugfix with tests for `find_resource` [\#189](https://github.com/OpenVoiceOS/OVOS-workshop/pull/189) ([NeonDaniel](https://github.com/NeonDaniel))

## [0.0.16a17](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a17) (2024-02-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a16...0.0.16a17)

**Fixed bugs:**

- fix: universal skills [\#187](https://github.com/OpenVoiceOS/OVOS-workshop/pull/187) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a16](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a16) (2024-02-21)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a15...0.0.16a16)

**Implemented enhancements:**

- feat/session\_location [\#186](https://github.com/OpenVoiceOS/OVOS-workshop/pull/186) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a15](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a15) (2024-02-07)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a14...0.0.16a15)

**Merged pull requests:**

- ocp metadata in init method [\#185](https://github.com/OpenVoiceOS/OVOS-workshop/pull/185) ([NeonJarbas](https://github.com/NeonJarbas))

## [0.0.16a14](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a14) (2024-02-06)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a13...0.0.16a14)

**Implemented enhancements:**

- add skill ressources inventory [\#184](https://github.com/OpenVoiceOS/OVOS-workshop/pull/184) ([emphasize](https://github.com/emphasize))

**Closed issues:**

- SkillResources: add method to create resource/intent test yaml files [\#180](https://github.com/OpenVoiceOS/OVOS-workshop/issues/180)

## [0.0.16a13](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a13) (2024-01-31)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a12...0.0.16a13)

**Fixed bugs:**

- BaseSkill.schedule\_repeating\_event has wrong type annotation [\#128](https://github.com/OpenVoiceOS/OVOS-workshop/issues/128)

**Merged pull requests:**

- chore: fix type hints [\#183](https://github.com/OpenVoiceOS/OVOS-workshop/pull/183) ([mikejgray](https://github.com/mikejgray))

## [0.0.16a12](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a12) (2024-01-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a11...0.0.16a12)

**Implemented enhancements:**

- refactor/homescreen [\#182](https://github.com/OpenVoiceOS/OVOS-workshop/pull/182) ([NeonJarbas](https://github.com/NeonJarbas))

## [0.0.16a11](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a11) (2024-01-24)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a10...0.0.16a11)

## [0.0.16a10](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a10) (2024-01-24)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a9...0.0.16a10)

**Fixed bugs:**

- fix/skill\_name [\#179](https://github.com/OpenVoiceOS/OVOS-workshop/pull/179) ([JarbasAl](https://github.com/JarbasAl))
- fix/sounds\_in\_docker [\#178](https://github.com/OpenVoiceOS/OVOS-workshop/pull/178) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a9](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a9) (2024-01-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a8...0.0.16a9)

**Fixed bugs:**

- fix/self.name usages [\#177](https://github.com/OpenVoiceOS/OVOS-workshop/pull/177) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a8](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a8) (2024-01-12)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a7...0.0.16a8)

**Implemented enhancements:**

- feat/stop\_per\_session [\#169](https://github.com/OpenVoiceOS/OVOS-workshop/pull/169) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a7](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a7) (2024-01-12)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a6...0.0.16a7)

## [0.0.16a6](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a6) (2024-01-12)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a5...0.0.16a6)

**Implemented enhancements:**

- feat/OCP csv keyword files support [\#174](https://github.com/OpenVoiceOS/OVOS-workshop/pull/174) ([NeonJarbas](https://github.com/NeonJarbas))

## [0.0.16a5](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a5) (2024-01-08)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a4...0.0.16a5)

**Implemented enhancements:**

- feat/ocp\_voc\_match [\#172](https://github.com/OpenVoiceOS/OVOS-workshop/pull/172) ([NeonJarbas](https://github.com/NeonJarbas))

## [0.0.16a4](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a4) (2024-01-06)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a3...0.0.16a4)

**Fixed bugs:**

- When a skill reload fails then try and clean up [\#173](https://github.com/OpenVoiceOS/OVOS-workshop/pull/173) ([lbt](https://github.com/lbt))

## [0.0.16a3](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a3) (2024-01-06)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a2...0.0.16a3)

**Fixed bugs:**

- FallbackSkill `__new__()` fails for FallbackSkillV1 [\#170](https://github.com/OpenVoiceOS/OVOS-workshop/issues/170)
- Just publish the skill\_id without the extra ":" [\#171](https://github.com/OpenVoiceOS/OVOS-workshop/pull/171) ([lbt](https://github.com/lbt))

## [0.0.16a2](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a2) (2023-12-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a1...0.0.16a2)

**Fixed bugs:**

- fix/loading\_failure\_logs\_even\_if\_loaded [\#168](https://github.com/OpenVoiceOS/OVOS-workshop/pull/168) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a1) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.15...0.0.16a1)

**Merged pull requests:**

- packaging/update\_imports [\#167](https://github.com/OpenVoiceOS/OVOS-workshop/pull/167) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.15](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.15) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.15a6...0.0.15)

## [0.0.15a6](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.15a6) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.15a5...0.0.15a6)

**Merged pull requests:**

- Update requirements.txt [\#165](https://github.com/OpenVoiceOS/OVOS-workshop/pull/165) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.15a5](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.15a5) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.15a4...0.0.15a5)

**Fixed bugs:**

- if it quacks like a duck... [\#164](https://github.com/OpenVoiceOS/OVOS-workshop/pull/164) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.15a4](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.15a4) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.15a3...0.0.15a4)

**Fixed bugs:**

- adapt backwards compat via metaclass [\#163](https://github.com/OpenVoiceOS/OVOS-workshop/pull/163) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.15a3](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.15a3) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.15a2...0.0.15a3)

**Fixed bugs:**

- adapt backwards compat [\#162](https://github.com/OpenVoiceOS/OVOS-workshop/pull/162) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.15a2](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.15a2) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.15a1...0.0.15a2)

**Fixed bugs:**

- fix skill\_directories [\#161](https://github.com/OpenVoiceOS/OVOS-workshop/pull/161) ([JarbasAl](https://github.com/JarbasAl))

**Closed issues:**

- `NameError: name '_get_skill_dirs' is not defined.` [\#159](https://github.com/OpenVoiceOS/OVOS-workshop/issues/159)

## [0.0.15a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.15a1) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.14...0.0.15a1)

**Fixed bugs:**

- update imports [\#160](https://github.com/OpenVoiceOS/OVOS-workshop/pull/160) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.14](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.14) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.14a1...0.0.14)

## [0.0.14a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.14a1) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a24...0.0.14a1)

**Merged pull requests:**

- stable deps [\#157](https://github.com/OpenVoiceOS/OVOS-workshop/pull/157) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a24](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a24) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a23...0.0.13a24)

**Merged pull requests:**

- Update requirements.txt [\#155](https://github.com/OpenVoiceOS/OVOS-workshop/pull/155) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a23](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a23) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a22...0.0.13a23)

**Merged pull requests:**

- Update stable requirements.txt [\#154](https://github.com/OpenVoiceOS/OVOS-workshop/pull/154) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a22](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a22) (2023-12-28)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a21...0.0.13a22)

**Merged pull requests:**

- refactor/move\_from\_utils [\#153](https://github.com/OpenVoiceOS/OVOS-workshop/pull/153) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a21](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a21) (2023-12-12)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a20...0.0.13a21)

**Implemented enhancements:**

- option to remove fallback \(handler\) [\#150](https://github.com/OpenVoiceOS/OVOS-workshop/pull/150) ([emphasize](https://github.com/emphasize))

## [0.0.13a20](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a20) (2023-11-21)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a19...0.0.13a20)

**Fixed bugs:**

- fix/get\_response\_session [\#149](https://github.com/OpenVoiceOS/OVOS-workshop/pull/149) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a19](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a19) (2023-11-16)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a18...0.0.13a19)

**Fixed bugs:**

- Fix Padatious intent handler registration with multiple native languages [\#148](https://github.com/OpenVoiceOS/OVOS-workshop/pull/148) ([NeonDaniel](https://github.com/NeonDaniel))

## [0.0.13a18](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a18) (2023-11-02)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a17...0.0.13a18)

**Implemented enhancements:**

- Allows wait argument to be int value for seconds [\#146](https://github.com/OpenVoiceOS/OVOS-workshop/pull/146) ([jaredcobb](https://github.com/jaredcobb))

## [0.0.13a17](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a17) (2023-10-18)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a16...0.0.13a17)

**Implemented enhancements:**

- feat/handle\_hex\_audiodata [\#145](https://github.com/OpenVoiceOS/OVOS-workshop/pull/145) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a16](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a16) (2023-10-13)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a15...0.0.13a16)

**Implemented enhancements:**

- Refactor/converse messages [\#144](https://github.com/OpenVoiceOS/OVOS-workshop/pull/144) ([emphasize](https://github.com/emphasize))

## [0.0.13a15](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a15) (2023-10-10)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a14...0.0.13a15)

**Implemented enhancements:**

- feat/extend\_ovosskill [\#143](https://github.com/OpenVoiceOS/OVOS-workshop/pull/143) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a14](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a14) (2023-10-10)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a13...0.0.13a14)

**Implemented enhancements:**

- Add Russian noise words [\#136](https://github.com/OpenVoiceOS/OVOS-workshop/pull/136) ([putnik](https://github.com/putnik))

## [0.0.13a13](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a13) (2023-10-10)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a12...0.0.13a13)

**Implemented enhancements:**

- CommonQuerySkill handler complete event and tests [\#142](https://github.com/OpenVoiceOS/OVOS-workshop/pull/142) ([NeonDaniel](https://github.com/NeonDaniel))

## [0.0.13a12](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a12) (2023-10-06)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a11...0.0.13a12)

**Fixed bugs:**

- fix mic listen message destination [\#141](https://github.com/OpenVoiceOS/OVOS-workshop/pull/141) ([emphasize](https://github.com/emphasize))

## [0.0.13a11](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a11) (2023-10-03)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a10...0.0.13a11)

**Merged pull requests:**

- unittests/end2end [\#140](https://github.com/OpenVoiceOS/OVOS-workshop/pull/140) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a10](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a10) (2023-10-03)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a9...0.0.13a10)

**Fixed bugs:**

- fix/get\_response\_reprompting [\#139](https://github.com/OpenVoiceOS/OVOS-workshop/pull/139) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a9](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a9) (2023-10-02)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a8...0.0.13a9)

**Fixed bugs:**

- fix/get\_response\_return\_val [\#138](https://github.com/OpenVoiceOS/OVOS-workshop/pull/138) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a8](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a8) (2023-10-02)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a7...0.0.13a8)

**Fixed bugs:**

- fix/get\_response\_message\_context [\#137](https://github.com/OpenVoiceOS/OVOS-workshop/pull/137) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a7](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a7) (2023-09-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a6...0.0.13a7)

**Fixed bugs:**

- fix/fallbackV1 [\#135](https://github.com/OpenVoiceOS/OVOS-workshop/pull/135) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a6](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a6) (2023-09-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a5...0.0.13a6)

**Merged pull requests:**

- fallback/no\_make\_active [\#134](https://github.com/OpenVoiceOS/OVOS-workshop/pull/134) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a5](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a5) (2023-09-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a4...0.0.13a5)

## [0.0.13a4](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a4) (2023-09-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a3...0.0.13a4)

**Merged pull requests:**

- refactor/merge BaseSkill and OVOSSkill [\#133](https://github.com/OpenVoiceOS/OVOS-workshop/pull/133) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a3](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a3) (2023-09-21)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a2...0.0.13a3)

**Implemented enhancements:**

- feat/compat\_handler\_decorator [\#131](https://github.com/OpenVoiceOS/OVOS-workshop/pull/131) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a2](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a2) (2023-09-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.13a1...0.0.13a2)

**Implemented enhancements:**

- feat/sounds\_playback in ovos-audio [\#129](https://github.com/OpenVoiceOS/OVOS-workshop/pull/129) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.13a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.13a1) (2023-09-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.12...0.0.13a1)

**Fixed bugs:**

- fix/abstract app init [\#130](https://github.com/OpenVoiceOS/OVOS-workshop/pull/130) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.12](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.12) (2023-07-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.12a50...0.0.12)

## [0.0.12a50](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.12a50) (2023-07-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.12a49...0.0.12a50)

**Merged pull requests:**

- Add description to setup.py to fix \#125 [\#126](https://github.com/OpenVoiceOS/OVOS-workshop/pull/126) ([NeonDaniel](https://github.com/NeonDaniel))

## [0.0.12a49](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.12a49) (2023-07-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a48...0.0.12a49)

**Merged pull requests:**

- Update automation to latest standards [\#125](https://github.com/OpenVoiceOS/OVOS-workshop/pull/125) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a48](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a48) (2023-07-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a47...V0.0.12a48)

**Merged pull requests:**

- Update dependencies to stable versions [\#124](https://github.com/OpenVoiceOS/OVOS-workshop/pull/124) ([NeonDaniel](https://github.com/NeonDaniel))
- Fix codecov automation [\#123](https://github.com/OpenVoiceOS/OVOS-workshop/pull/123) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a47](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a47) (2023-07-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a46...V0.0.12a47)

**Merged pull requests:**

- Minor import and logging updates to troubleshoot logged warnings [\#122](https://github.com/OpenVoiceOS/OVOS-workshop/pull/122) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a46](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a46) (2023-07-15)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a45...V0.0.12a46)

**Merged pull requests:**

- Loosen ovos-backend-client dependency to allow latest stable version [\#121](https://github.com/OpenVoiceOS/OVOS-workshop/pull/121) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a45](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a45) (2023-07-14)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a44...V0.0.12a45)

**Fixed bugs:**

- PHAL and admin PHAL failures to successfully initialize started evening of Jul 13 [\#119](https://github.com/OpenVoiceOS/OVOS-workshop/issues/119)
- fix init [\#120](https://github.com/OpenVoiceOS/OVOS-workshop/pull/120) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a44](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a44) (2023-07-13)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a43...V0.0.12a44)

**Merged pull requests:**

- Update OVOSAbstractApplication and unit tests [\#118](https://github.com/OpenVoiceOS/OVOS-workshop/pull/118) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a43](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a43) (2023-07-13)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a42...V0.0.12a43)

**Merged pull requests:**

- Fix language handling in intent and entity file resolution [\#117](https://github.com/OpenVoiceOS/OVOS-workshop/pull/117) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a42](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a42) (2023-07-13)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a41...V0.0.12a42)

**Merged pull requests:**

- Unit tests and improvements to settings change callback [\#116](https://github.com/OpenVoiceOS/OVOS-workshop/pull/116) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a41](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a41) (2023-07-12)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a40...V0.0.12a41)

## [V0.0.12a40](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a40) (2023-07-12)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a39...V0.0.12a40)

**Merged pull requests:**

- Update `default_shutdown` with unit tests [\#115](https://github.com/OpenVoiceOS/OVOS-workshop/pull/115) ([NeonDaniel](https://github.com/NeonDaniel))
- Docstrings, Annotation, and Outlined unit tests [\#111](https://github.com/OpenVoiceOS/OVOS-workshop/pull/111) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a39](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a39) (2023-07-12)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a38...V0.0.12a39)

**Merged pull requests:**

- Add locking around skill settings changes [\#114](https://github.com/OpenVoiceOS/OVOS-workshop/pull/114) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a38](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a38) (2023-07-12)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a37...V0.0.12a38)

**Merged pull requests:**

- Update requirements.txt [\#112](https://github.com/OpenVoiceOS/OVOS-workshop/pull/112) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a37](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a37) (2023-07-10)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a36...V0.0.12a37)

**Merged pull requests:**

- Add docstrings and unit tests for app.py [\#110](https://github.com/OpenVoiceOS/OVOS-workshop/pull/110) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a36](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a36) (2023-07-10)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a35...V0.0.12a36)

**Implemented enhancements:**

- Skills module tests, docstrings, and annotations [\#108](https://github.com/OpenVoiceOS/OVOS-workshop/pull/108) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a35](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a35) (2023-07-07)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a34...V0.0.12a35)

**Merged pull requests:**

- Decorator module tests, docstrings, and annotations [\#107](https://github.com/OpenVoiceOS/OVOS-workshop/pull/107) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a34](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a34) (2023-07-06)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a33...V0.0.12a34)

**Merged pull requests:**

- Refactor `SkillGUI` with unit tests [\#106](https://github.com/OpenVoiceOS/OVOS-workshop/pull/106) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a33](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a33) (2023-07-04)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a32...V0.0.12a33)

**Fixed bugs:**

- fix/play\_audio [\#105](https://github.com/OpenVoiceOS/OVOS-workshop/pull/105) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a32](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a32) (2023-06-24)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a31...V0.0.12a32)

**Implemented enhancements:**

- feat/session\_id\_wait\_while\_speaking [\#102](https://github.com/OpenVoiceOS/OVOS-workshop/pull/102) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a31](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a31) (2023-06-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a30...V0.0.12a31)

**Fixed bugs:**

- fix: skill reloading broken [\#101](https://github.com/OpenVoiceOS/OVOS-workshop/pull/101) ([fidesachates](https://github.com/fidesachates))

## [V0.0.12a30](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a30) (2023-06-16)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a29...V0.0.12a30)

## [V0.0.12a29](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a29) (2023-06-15)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a28...V0.0.12a29)

## [V0.0.12a28](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a28) (2023-06-14)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a27...V0.0.12a28)

## [V0.0.12a27](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a27) (2023-05-17)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a26...V0.0.12a27)

## [V0.0.12a26](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a26) (2023-05-17)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a25...V0.0.12a26)

## [V0.0.12a25](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a25) (2023-05-03)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a24...V0.0.12a25)

## [V0.0.12a24](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a24) (2023-05-01)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a23...V0.0.12a24)

## [V0.0.12a23](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a23) (2023-04-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a22...V0.0.12a23)

## [V0.0.12a22](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a22) (2023-04-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a21...V0.0.12a22)

## [V0.0.12a21](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a21) (2023-04-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a20...V0.0.12a21)

## [V0.0.12a20](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a20) (2023-04-26)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a19...V0.0.12a20)

## [V0.0.12a19](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a19) (2023-04-26)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a18...V0.0.12a19)

## [V0.0.12a18](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a18) (2023-04-25)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a17...V0.0.12a18)

## [V0.0.12a17](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a17) (2023-04-24)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a16...V0.0.12a17)

## [V0.0.12a16](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a16) (2023-04-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a15...V0.0.12a16)

## [V0.0.12a15](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a15) (2023-04-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a14...V0.0.12a15)

## [V0.0.12a14](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a14) (2023-04-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a13...V0.0.12a14)

## [V0.0.12a13](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a13) (2023-04-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a12...V0.0.12a13)

## [V0.0.12a12](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a12) (2023-04-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a11...V0.0.12a12)

## [V0.0.12a11](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a11) (2023-04-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a10...V0.0.12a11)

## [V0.0.12a10](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a10) (2023-04-21)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a9...V0.0.12a10)

## [V0.0.12a9](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a9) (2023-04-21)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a8...V0.0.12a9)

## [V0.0.12a8](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a8) (2023-04-21)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a7...V0.0.12a8)

## [V0.0.12a7](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a7) (2023-04-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a6...V0.0.12a7)

## [V0.0.12a6](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a6) (2023-04-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a5...V0.0.12a6)

## [V0.0.12a5](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a5) (2023-04-18)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a4...V0.0.12a5)

## [V0.0.12a4](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a4) (2023-04-14)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a3...V0.0.12a4)

## [V0.0.12a3](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a3) (2023-04-05)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a2...V0.0.12a3)

## [V0.0.12a2](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a2) (2023-03-02)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a1...V0.0.12a2)

## [V0.0.12a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a1) (2023-03-02)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.11...V0.0.12a1)

## [V0.0.11](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.11) (2023-02-25)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.11a6...V0.0.11)

## [V0.0.11a6](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.11a6) (2023-02-25)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.11a5...V0.0.11a6)

## [V0.0.11a5](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.11a5) (2023-02-09)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.11a4...V0.0.11a5)

## [V0.0.11a4](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.11a4) (2023-02-09)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.11a3...V0.0.11a4)

## [V0.0.11a3](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.11a3) (2023-02-02)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.11a2...V0.0.11a3)

## [V0.0.11a2](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.11a2) (2023-01-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.11a1...V0.0.11a2)

## [V0.0.11a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.11a1) (2023-01-28)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.10...V0.0.11a1)

## [V0.0.10](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.10) (2023-01-24)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.10a6...V0.0.10)

## [V0.0.10a6](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.10a6) (2023-01-24)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.10a5...V0.0.10a6)

## [V0.0.10a5](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.10a5) (2023-01-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.10a4...V0.0.10a5)

## [V0.0.10a4](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.10a4) (2023-01-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.10a3...V0.0.10a4)

## [V0.0.10a3](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.10a3) (2023-01-18)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.10a2...V0.0.10a3)

## [V0.0.10a2](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.10a2) (2023-01-17)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.10a1...V0.0.10a2)

## [V0.0.10a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.10a1) (2022-12-15)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.9...V0.0.10a1)

## [V0.0.9](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.9) (2022-10-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.9a1...V0.0.9)

## [V0.0.9a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.9a1) (2022-10-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.8...V0.0.9a1)

## [V0.0.8](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.8) (2022-10-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.8a6...V0.0.8)

## [V0.0.8a6](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.8a6) (2022-10-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.8a5...V0.0.8a6)

## [V0.0.8a5](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.8a5) (2022-10-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.8a4...V0.0.8a5)

## [V0.0.8a4](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.8a4) (2022-10-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.8a3...V0.0.8a4)

## [V0.0.8a3](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.8a3) (2022-10-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.8a2...V0.0.8a3)

## [V0.0.8a2](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.8a2) (2022-10-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.8a1...V0.0.8a2)

## [V0.0.8a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.8a1) (2022-09-13)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7...V0.0.8a1)

## [V0.0.7](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7) (2022-07-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a12...V0.0.7)

## [V0.0.7a12](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a12) (2022-07-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a11...V0.0.7a12)

## [V0.0.7a11](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a11) (2022-07-28)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a10...V0.0.7a11)

## [V0.0.7a10](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a10) (2022-07-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a9...V0.0.7a10)

## [V0.0.7a9](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a9) (2022-06-09)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a8...V0.0.7a9)

## [V0.0.7a8](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a8) (2022-06-02)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a7...V0.0.7a8)

## [V0.0.7a7](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a7) (2022-05-09)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a6...V0.0.7a7)

## [V0.0.7a6](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a6) (2022-05-09)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a5...V0.0.7a6)

## [V0.0.7a5](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a5) (2022-05-09)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a4...V0.0.7a5)

## [V0.0.7a4](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a4) (2022-05-07)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a3...V0.0.7a4)

## [V0.0.7a3](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a3) (2022-05-07)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a2...V0.0.7a3)

## [V0.0.7a2](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a2) (2022-05-07)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a1...V0.0.7a2)

## [V0.0.7a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a1) (2022-05-07)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.6...V0.0.7a1)

## [V0.0.6](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.6) (2022-03-03)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.6a1...V0.0.6)

## [V0.0.6a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.6a1) (2022-03-03)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.5...V0.0.6a1)

## [V0.0.5](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.5) (2022-02-25)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.5a12...V0.0.5)

## [V0.0.5a12](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.5a12) (2022-02-25)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/d9261b124f73a3e4d50c6edfcd9c2243b2bc3cf6...V0.0.5a12)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
